AppFlowyBoardConfig class

Constructors

AppFlowyBoardConfig({double boardCornerRadius = 6.0, double groupCornerRadius = 6.0, Color groupBackgroundColor = Colors.transparent, EdgeInsets groupMargin = const EdgeInsets.symmetric(horizontal: 8), EdgeInsets groupHeaderPadding = const EdgeInsets.symmetric(horizontal: 16), EdgeInsets groupBodyPadding = const EdgeInsets.symmetric(horizontal: 12), EdgeInsets groupFooterPadding = const EdgeInsets.symmetric(horizontal: 12), bool stretchGroupHeight = true, EdgeInsets cardMargin = const EdgeInsets.symmetric(horizontal: 3, vertical: 4)})
const

Properties

boardCornerRadius double
final
cardMargin EdgeInsets
final
groupBackgroundColor Color
final
groupBodyPadding EdgeInsets
final
groupCornerRadius double
final
groupFooterPadding EdgeInsets
final
groupHeaderPadding EdgeInsets
final
groupMargin EdgeInsets
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stretchGroupHeight bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited